phoneapp/phoneuiutils/src/tphonecmdparamglobalnote.cpp
branchRCL_3
changeset 24 41a7f70b3818
parent 0 5f000ab63145
child 25 5266b1f337bd
--- a/phoneapp/phoneuiutils/src/tphonecmdparamglobalnote.cpp	Thu Aug 19 09:54:27 2010 +0300
+++ b/phoneapp/phoneuiutils/src/tphonecmdparamglobalnote.cpp	Tue Aug 31 15:14:29 2010 +0300
@@ -31,12 +31,12 @@
 //
 EXPORT_C TPhoneCmdParamGlobalNote::TPhoneCmdParamGlobalNote():
     TPhoneCommandParam(),
-    iType( EAknGlobalErrorNote ),
+    iType( EPhoneNotificationDialog ),
     iTextResourceId( 0 ),
     iText( KNullDesC ),
-    iTone( EAvkonSIDErrorTone ),
-    iWaitforReady ( EFalse )
-    ,iSoftkeys( 0 )
+    iTimeout( 0 ),
+    iNotificationDialog( EFalse ),
+    iCauseCode( KErrNotFound ) 
     {
     iParamId = EPhoneParamIdGlobalNote;
     }
@@ -47,7 +47,7 @@
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C void TPhoneCmdParamGlobalNote::SetType( TAknGlobalNoteType aType )
+EXPORT_C void TPhoneCmdParamGlobalNote::SetType( /*TAknGlobalNoteType*/ PhoneNotificationType aType )
    {
    iType = aType;   
    }
@@ -62,7 +62,7 @@
    TInt aTextResourceId )
    {
     __ASSERT_DEBUG( aTextResourceId, 
-    	Panic( EPhoneUtilsParameterNotInitialized ) );
+        Panic( EPhoneUtilsParameterNotInitialized ) );
    iTextResourceId = aTextResourceId;   
    }
 
@@ -79,37 +79,39 @@
    }
 
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::SetTone
 // Sets the global note tone
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C void TPhoneCmdParamGlobalNote::SetTone( TInt aTone )
-   {
-   iTone = aTone;   
-   }
+EXPORT_C void TPhoneCmdParamGlobalNote::SetTimeout( TInt aTimeout )
+{
+    iTimeout = aTimeout;
+}
 
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::SetWaitForReady
 // Sets the note to wait for completed
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C void TPhoneCmdParamGlobalNote::SetWaitForReady( TBool aStatus )
-   {
-   iWaitforReady = aStatus;   
-   }
+EXPORT_C void TPhoneCmdParamGlobalNote::SetNotificationDialog( 
+        TBool aNotificationDialog )
+{
+    iNotificationDialog = aNotificationDialog;
+}
 
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::SetSoftkeys
 // Sets the global note softkeys
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C void TPhoneCmdParamGlobalNote::SetSoftkeys( TInt aSoftkeys )
-   {
-   iSoftkeys = aSoftkeys;   
-   }
+EXPORT_C void TPhoneCmdParamGlobalNote::SetCauseCode( 
+        TInt aCauseCode )
+{
+    iCauseCode = aCauseCode;
+}
 
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::Type
@@ -117,7 +119,7 @@
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C TAknGlobalNoteType TPhoneCmdParamGlobalNote::Type() const
+EXPORT_C /*TAknGlobalNoteType*/ PhoneNotificationType TPhoneCmdParamGlobalNote::Type() const
    {
    return iType;
    }
@@ -145,36 +147,33 @@
    }
 
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::Tone
 // Returns the note tone
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C TInt TPhoneCmdParamGlobalNote::Tone() const
-   {
-   return iTone;
-   }
+EXPORT_C TInt TPhoneCmdParamGlobalNote::Timeout() const
+    {
+    return iTimeout;
+    }
 
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::WaitForReady
-// Returns the status of wait for completed
-// (other items were commented in a header).
+// TPhoneCmdParamGlobalNote::NotificationDialog
+// Returns the notification dialog flag.
 // ---------------------------------------------------------
 //
-EXPORT_C TBool TPhoneCmdParamGlobalNote::WaitForReady() const
-   {
-   return iWaitforReady;
-   }
-   
+EXPORT_C TBool TPhoneCmdParamGlobalNote::NotificationDialog() const
+    {
+    return iNotificationDialog;
+    }
+
 // ---------------------------------------------------------
 // TPhoneCmdParamGlobalNote::Softkeys
 // Returns the note softkeys
 // (other items were commented in a header).
 // ---------------------------------------------------------
 //
-EXPORT_C TInt TPhoneCmdParamGlobalNote::Softkeys() const
-   {
-   return iSoftkeys;
-   }
+EXPORT_C TInt TPhoneCmdParamGlobalNote::CauseCode() const
+    {
+    return iCauseCode;
+    }
 
 //  End of File
@@ -79,37 +79,39 @@
 
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::SetTone
-// Sets the global note tone
+// TPhoneCmdParamGlobalNote::SetTimeout
+// Sets the timeout value for a note.
 // (other items were commented in a header).
 // ---------------------------------------------------------
@@ -79,37 +79,39 @@
 
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::SetWaitForReady
-// Sets the note to wait for completed
+// TPhoneCmdParamGlobalNote::SetNotificationDialog
+// Sets the notification dialog flag.
 // (other items were commented in a header).
 // ---------------------------------------------------------
@@ -79,37 +79,39 @@
 
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::SetSoftkeys
-// Sets the global note softkeys
+// TPhoneCmdParamGlobalNote::SetCauseCode
+// Sets the cause code.
 // (other items were commented in a header).
 // ---------------------------------------------------------
@@ -145,36 +147,33 @@
 
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::Tone
-// Returns the note tone
-// (other items were commented in a header).
+// TPhoneCmdParamGlobalNote::Timeout
+// Returns the timeout value.
 // ---------------------------------------------------------
 //
@@ -145,36 +147,33 @@
 // ---------------------------------------------------------
-// TPhoneCmdParamGlobalNote::Softkeys
-// Returns the note softkeys
-// (other items were commented in a header).
+// TPhoneCmdParamGlobalNote::CauseCode
+// Returns the cause code.
 // ---------------------------------------------------------
 //